@@ -171,7 +171,8 @@ ForecastYieldsSepQ <- function(ModelType, ModelPara, InputsForOutputs, FactorLab
 
       tol <- 1e-4
 
-      FullModelParaList[[ModelType]][[Economies[i]]] <- Optimization(f, tol, varargin, FactorLabels, Economies, ModelType)$Summary
+      FullModelParaList[[ModelType]][[Economies[i]]] <- Optimization(f, tol, varargin, FactorLabels, Economies, ModelType,
+                                                                     JLLinputs, GVARinputs)$Summary
 
 
       # 3) Forecasting
@@ -213,6 +214,7 @@ ForecastYieldsSepQ <- function(ModelType, ModelPara, InputsForOutputs, FactorLab
 
       print(paste(ModelType, Economies[i], ": Out-of-sample forecast for information set available until", ForecastDate))
 
+      saveRDS(OutofSampleForecast, paste(tempdir(),"/Forecast_", InputsForOutputs$'Label Outputs','.rds',sep=""))
     }
   }
 
@@ -343,7 +345,7 @@ ForecastYieldsJointQ <- function(ModelType, ModelPara, InputsForOutputs, FactorL
 
 
       invisible(utils::capture.output(FullModelParaList[[ModelType]] <- Optimization(f, tol, varargin, FactorLabels,
-                                                     Economies, ModelType, JLLinputs)$Summary))
+                                                     Economies, ModelType, JLLinputs, GVARinputs)$Summary))
 
 
       # 3) Forecasting
@@ -387,7 +389,7 @@ ForecastYieldsJointQ <- function(ModelType, ModelPara, InputsForOutputs, FactorL
 
       print(paste(ModelType, ": Out-of-sample forecast for information set available until", ForecastDate))
 
-
+      saveRDS(OutofSampleForecast, paste(tempdir(),"/Forecast_", InputsForOutputs$'Label Outputs','.rds',sep=""))
   }
 
 
@@ -397,6 +399,9 @@ ForecastYieldsJointQ <- function(ModelType, ModelPara, InputsForOutputs, FactorL
   names(RMSE) <- "RMSE"
   OutofSampleForecast <- append(OutofSampleForecast[[ModelType]], RMSE)
 
+
+  saveRDS(OutofSampleForecast, paste(tempdir(),"/Forecast_", InputsForOutputs$'Label Outputs','.rds',sep=""))
+
   return(OutofSampleForecast)
 
 }
